/** 
 * 全局对象
 */
var ebdpui = window["ebdpui"] || {};
/**
 * 定义一个全局空对象，如果根据key获取不到value、keyedCollection或者indexedCollection，则返回空对象 
 */
function Empty() {}

var IFOP_INIT_DATA_ITEM_KEY = "__EBDPINITDATAITEMKEY__"; 
var IFOP_SESSIONANDOP_DATA_ITEM_KEY = "__EBDPSESSIONANDOPDATEITEMKEY__";
var IFOP_DEBUG_FLAG1 = "_initDataForDebug__";
var IFOP_DEBUG_FLAG2 = "__sessionAndOpDataForDebug__";


/**
 * 从客户端获取数据模块，包括两部分，一部分是页面head里获取手机型号等信息，另一部分是页面onload里获取session和op信息
 */
ebdpui.native = (function(){
	/**
	 * 页面渲染到head时，从客户端获取手机型号等信息
	 * @return {String} json序列化字符串
	 */
	function _getInitData() {
		var _data = ''; 
		/** 先判断从localStoreage中获取 */
		var _localStorage = ebdpui.cache.getLocalStorage();
		if(!!_localStorage.getItem(IFOP_INIT_DATA_ITEM_KEY)) {
			//从客户端获取
			if (ICBCUtilTools.isAndroid()) {
				ICBCUtilTools.callNative("Native", "getInitDataEnhanced", function(_data){
					//存储到localStorage中
					_localStorage.setItem(IFOP_INIT_DATA_ITEM_KEY, _data);
				});
				
			}else if(ICBCUtilTools.isiPhone()) {
				ICBCUtilTools.callNative("Native", "getInitDataEnhanced", {}, function(reponse){
					_localStorage.setItem(IFOP_INIT_DATA_ITEM_KEY, reponse);
				});
			}
			
		}else {
			//从localStorage中获取
			_data = _localStorage.getItem(IFOP_INIT_DATA_ITEM_KEY);
		}
		return _data;
	}
	
	
	/**
	 * 判断是否是Android系统
	 * @return (Boolean)
	 */
	function _isAndroid() {
		if(window.navigator.userAgent.toLowerCase().indexOf("android") != -1) {
			return true;
		}
		return false;
	}
	
	/**
	 * 判断是否是iOS系统
	 * @return (Boolean)
	 */
	function _isIOS() {
		if(window.navigator.userAgent.toLowerCase().indexOf("ios") != -1) { 
			return true;
		}
		return true;
	}
	
	/**
	 * 获取客户端数据
	 * @return (String)　json序列化字符串
	 */
	function _getSessionAndOpData(theFunc) {
		
		if (ICBCUtilTools.isAndroid()) {
			ICBCUtilTools.callNative("Native", "getSessionAndOpDataEnhanced", {}, theFunc); 
			//return _data;
		}else if(ICBCUtilTools.isiPhone()) {
			//alert("hello world");
			ICBCUtilTools.callNative("Native", "getSessionAndOpDataEnhanced", {}, function(response){ 
				theFunc(response); 
			});
		}
	}
	
	/**
	 * 获取客户端数据，为debug时候使用
	 * @return {String} json序列化字符串
	 */
	function _getSessionAndOpDataForDebug() {
		var _sessionStorage = ebdpui.cache.getSessionStorage();
		return _sessionStorage.getItem(IFOP_SESSIONANDOP_DATA_ITEM_KEY);
	}
	
	/**
	 * 点击返回
	 */
	function _goBack() {
		if (ICBCUtilTools.isAndroid()) {
			ICBCUtilTools.callNative("Native", "goBackEnhanced", {}, null); 
		}else if(ICBCUtilTools.isiPhone()) {
			ICBCUtilTools.callNative("Native", "goBackEnhanced", {}, null);
		}
	}
	
	/**
	 * form拦截后，设置form数据
	 * @param formJsonData
	 */
	function _setFormData(formJsonData) {
		ICBCUtilTools.callNative("Native", "setFormDataEnhanced", formJsonData, null); 
	}
	
	return {
		getInitData: _getInitData,//页面渲染到head时，从客户端获取后续逻辑校验数据
		getSessionAndOpData: _getSessionAndOpData,//页面在onload时，从客户端获取session和op的数据\
		getSessionAndOpDataForDebug:_getSessionAndOpDataForDebug,
		goBack: _goBack ,
		setFormData: _setFormData
	}; 
})();


/**
 * 存储模块，目前仅提供内部native和debug模块使用
 */
ebdpui.cache = (function(){
	function createStorage(storageObj) {		
		return {
			length: storageObj.length,
			key: function(index) {
				var i=0;
				for(key in storageObj) {
					if(i == index) {
						return key;
					}
					i++;
				}
			},
			setItem: function(key,value) {
					storageObj[key.toString()] = value.toString();
			},
			getItem: function(key) {
				if(key in storageObj) {
					return storageObj[key].toString();
				} else {
					return null;
				}
			},
			removeItem: function(key) {
				if(key in storageObj) {
					delete storageObj[key];
				}
			},
			clear: function() {
				storageObj={};
			}
		};
	}
	return {
		getSessionStorage: function(){
			if(window.sessionStorage) {
				return window.sessionStorage;
			} else {
				return createStorage({});
			}
		},
		getLocalStorage: function(){
			if(window.localStorage) {
				return window.localStorage;
			} else {
				return createStorage({});
			}
		}
	};
})();


/**
 * json反序列化对象模块
 */
ebdpui.unformat = (function(){
	
	/** 用于initData反序列化对象实例 */
	var initJsonStructFormatInstance = null;
	/** 用于session data和op data反序列化对象实例 */
	var jsonStructFormatInstance = null;
	/** session data对应key值，默认为sessionData */
	var _sessionDataKey = null;
	/** op data对应key值，默认为opData */
	var _opDataKey = null;
	/** session data和op data组合对象实例 */
	var composedJsonStructFormatInstance = null;
	
	/**
	 * KeyedCollection数据结构
	 * @param {Object} data	数据对象
	 */
	function KeyedCollection(obj) {
		if(obj) {
			this.data = obj; 
		}else {
			this.data = {};
		}
	}
	
	/**
	 * 根据key获取value
	 * @param {Object} key	传入的key值
	 * @return {Object} Value 返回的value值
	 */
	KeyedCollection.prototype.getValueAt = function(key) {
		var ret = this.data;
		var keyParts = key.split(".");
		for(var i=0,j=keyParts.length;i<j;i++) {
			ret = ret[keyParts[i]];
			if(typeof ret == "undefined" || ret == undefined) {
				//ret = "";
				ret = new Empty();
			}
		}
		if(typeof ret == "object" && !(ret instanceof Empty)) { 
			if(ret instanceof Array) {
				ret = new IndexedCollection(ret); 
			}else {
				ret = new KeyedCollection(ret);	
			}
		}
		return ret;
	};

	/**
	 * 设置key-value
	 * @param {Object} key	传入的key值
	 * @param {Object} Value 设置的value值
	 */
	KeyedCollection.prototype.setValueAt = function(key,value) {
		if (key != null && key != "" && value != null && value != "") {
	        this.data[key] = value;
	    }
	};

	/**
	 * 增加元素key-value
	 * @param {Object} key	传入的key值
	 * @param {Object} Value 增加的value值
	 */    
	KeyedCollection.prototype.addElement = function(key, value){
	    if (key != null && key != "" && value != null && value != "") {
	        this.data[key] = value;
	    }
	};

	/**
	 * 获取该层KCOLL的key的集合，可以用与KCOLL的数据遍历
	 * @return {Object}  Value 返回的集合
	 */
	KeyedCollection.prototype.getEnumeration = function(){
	    var i = 0;
	    var ret = {};
	    for (o in this.data) {
	        ret[i] = o;
	        i++;
	    }
	    return ret;
	};

	/**
	 * 根据key获取KCOLL中的KeyedCollection
	 * @return {Object}  KeyedCollection 返回的KeyedCollection
	 */
	KeyedCollection.prototype.getKeyedCollection = function(key) {
		var ret = this.data[key];
		if(typeof ret == "undefined" || ret == undefined) {
			//ret = new KeyedCollection();
			return new Empty();
		}
		return new KeyedCollection(ret);
	};

	/**
	 * 根据key获取KCOLL中的IndexedCollection
	 * @return {Object}  IndexedCollection 返回的IndexedCollection
	 */
	KeyedCollection.prototype.getIndexedCollection = function(key){
	    var ret = this.data[key];
	    if (ret == undefined) {
	        //ret = new Array();
	    	return new Empty();
	    }
	    return new IndexedCollection(ret);
	};

	/**
	 * KeyedCollection的序列化函数
	 * @return {String}  序列化字符串
	 */    
	KeyedCollection.prototype.toString = function(){
	    return JSON.stringify(this.data);
	};

	/**
	 * IndexedCollection数据结构
	 * @param {Object} data	数据对象
	 */
	function IndexedCollection(data){  
	    if (data) {
	        this.data = data;
	    }
	    else {
	        this.data = [];
	    }
	};

	/**
	 * 返回数据长度
	 * @return {Integer}  包含的数据长度
	 */ 
	IndexedCollection.prototype.size = function(){
	    return this.data.length;
	};

	/**
	 * 返回该索引下的KeyedCollection数据
	 * @param {Integer} 索引值
	 * @return {KeyedCollection}  该索引下的KeyedCollection
	 */ 
	IndexedCollection.prototype.getElementAt = function(index){
	    return new KeyedCollection(this.data[index]);
	};

	/**
	 * 增加一个KeyedCollection元素
	 * @param {KeyedCollection}  待增加的KeyedCollection数据
	 */ 
	IndexedCollection.prototype.addElement = function(kc){
	    //this.data.push(kc.data);
		this.data.push(kc);
	};

	/**
	 * IndexedCollection的序列化函数
	 * @return {String}  序列化字符串
	 */  
	IndexedCollection.prototype.toString = function(){
	    return JSON.stringify(this.data);
	};
	
	/**
	 * JSONStructFormat是处理json反序列化的基类，其中的很多实现方法都要依照子类的实现。
	 * @param {Object} data	数据对象
	 */
	function JSONStructFormat(data){
	    if (data) {
	    	if(typeof data == 'object') {
	    		this.data = new KeyedCollection(data);  
	    	}else {
	    		jsonStartTime = new Date().getTime();
	    		this.data = new KeyedCollection(JSON.parse(data));
	    		jsonEndTime = new Date().getTime(); 
	    	}
	    }
	    else {
	        this.data = new KeyedCollection(); 
	    }
	}

	/**
	 * 对unfmtstr字符串进行unformat，需要子类进行具体的实现。
	 */
	JSONStructFormat.prototype.unformat = function(unfmtObj) { 
		var json = {};
	    if (typeof unfmtObj == "string") {
	        json = JSON.parse(unfmtObj);
	    }
	    else {
	        json = unfmtObj;
	    } 
	    for (o in json) {
	        this.setData(o, json[o]);
	    }
	};

	/**
	 * 向JSONStructFormat中设置值，需要子类自身实现。
	 * @param {Object} key		设置的key
	 * @param {Object} value	设置的value
	 */
	JSONStructFormat.prototype.setData = function(key, value){
		if (key == null || key == "" || value == null || value == "") {
	        return;
	    }
	    this.data.addElement(key, value);
	};

	/**
	 * 从JSONStructFormat中get值，需要子类自身实现
	 * @param {Object} key	获取的key
	 * @return Object 获取的对象
	 */
	JSONStructFormat.prototype.getData = function(key){
		if (key == null || key == "") {
	        return "";
	    }
	    else {
	        return this.data.getValueAt(key);
	    }
	};

	/**
	 * 得到内部引用的reference
	 * @return Object 获取的对象
	 */
	JSONStructFormat.prototype.getRefData = function(){
	    return this.data;
	};

	/**
	 * 设置内部引用的reference
	 * @param {Object} mObj	设置的对象
	 */
	JSONStructFormat.prototype.setRefData = function(mObj){
	    this.data = data;
	};

	/**-----------------------------------SessionJSONStructFormat定义-------------------------------*/
	/**
	 * SessionJSONStructFormat的具体实现
	 * @param {Object} data
	 */
	function SessionJSONStructFormat(data){
	    JSONStructFormat.call(this, data);
	}

	/** 
	 * 实现继承 
	 */
	SessionJSONStructFormat.prototype = new JSONStructFormat();
	SessionJSONStructFormat.prototype.constructor = JSONStructFormat; 

	/**-----------------------------------OpJSONStructFormat定义-------------------------------*/
	/**
	 * OpJSONStructFormat的具体实现
	 * @param {Object} data
	 */
	function OpJSONStructFormat(data) {
		JSONStructFormat.call(this,data); 
	}

	/**
	 * 实现继承
	 */
	OpJSONStructFormat.prototype = new JSONStructFormat();
	OpJSONStructFormat.prototype.constructor = JSONStructFormat;
	
	
	/**
	 * 提供一套接口，如果opData中没有查找到数据，则继续在sessionData中查找
	 * 
	 */
	function ComposedJSONStructFormat(sessionData, opData) {
		this.sessionData = sessionData;
		this.opData = opData;
	}
	
	/**
	 * 根据key获取value
	 * @param {Object} key	传入的key值
	 * @return {Object} Value 返回的value值
	 */
	ComposedJSONStructFormat.prototype.getValueAt = function(key) {
		var ret = this.opData.getValueAt(key);
		if(ret instanceof Empty) {
			ret = this.sessionData.getValueAt(key);
		}
		return ret;
	};
	
	/**
	 * 根据key获取KCOLL中的KeyedCollection
	 * @return {Object}  KeyedCollection 返回的KeyedCollection
	 */
	ComposedJSONStructFormat.prototype.getKeyedCollection = function(key) {
		var ret = this.opData.getKeyedCollection(key);
		if(ret instanceof Empty) {
			ret = this.sessionData.getKeyedCollection(key);
		}
		return ret;
	};
	
	/**
	 * 根据key获取KCOLL中的IndexedCollection
	 * @return {Object}  IndexedCollection 返回的IndexedCollection
	 */
	ComposedJSONStructFormat.prototype.getIndexedCollection = function(key){
		var ret = this.opData.getIndexedCollection(key);
		if(ret instanceof Empty) {
			ret = this.sessionData.getIndexedCollection(key);
		}
		return ret;
	};
	
	
	return {
		getInitInstance: function(initData) {//获取initData反序列化对象实例 
			try {
				if(!initJsonStructFormatInstance) {
					initJsonStructFormatInstance = new JSONStructFormat(initData?initData:{});
				}
				return initJsonStructFormatInstance;
			}catch(e) {
			}
		},
		
		getInitData: function() {//获取initData反序列化对象，以访问里面具体数据
			if(initJsonStructFormatInstance!=null) {
				return initJsonStructFormatInstance.getRefData();
			}else {
				return new JSONStructFormat();
			}
		},
		
		getInstance: function(initData){//获取sessionData和opData反序列化对象实例
			try { 
				if(!jsonStructFormatInstance){
					jsonStructFormatInstance = new JSONStructFormat(initData.data?initData.data:{});
					sessionDataKey = initData.sessionDataKey?initData.sessionDataKey:"sessionData";
					opDataKey = initData.opDataKey?initData.opDataKey:"opData"; 
				}else{
					//
				}
				return jsonStructFormatInstance; 
			}catch(e){
			}
		},
	
		getSessionData: function() {//获取sessionData的反序列化对象，以访问里面具体数据
			if(jsonStructFormatInstance != null) {
				return jsonStructFormatInstance.getRefData().getValueAt(sessionDataKey);
			}else {
				return new SessionJSONStructFormat();
			}
		},
		
		getOpData: function() {//获取opData反序列化对象，以访问里面具体数据
			if(jsonStructFormatInstance != null) {
				return jsonStructFormatInstance.getRefData().getValueAt(opDataKey); 
			}else { 
				return new OpJSONStructFormat();
			}
		},
		
		getData: function() {//获取sessionData和opData组合数据的反序列化对象，先从opData中取数据，如果不存在，则继续从sessionData中获取
			if(jsonStructFormatInstance != null) {
				if(composedJsonStructFormatInstance!=null) {
					return composedJsonStructFormatInstance;
				}else {
					composedJsonStructFormatInstance = new ComposedJSONStructFormat(jsonStructFormatInstance.getRefData().getValueAt(sessionDataKey), jsonStructFormatInstance.getRefData().getValueAt(opDataKey));
					return composedJsonStructFormatInstance; 
				}
			}else {
				return new JSONStructFormat(); 
			}
		}
	};
})();


/**
 * 注册页面渲染函数模块
 */
ebdpui.render = (function(){
	
	/** 存储执行函数的数组 */
	var funcArray = [];
	
	/**
	 * 注册一个执行函数
	 * @param {String} funcName：函数名称
	 * @param {Array} funcParam: 函数参数
	 * @param {Obj} namespace: 函数命名空间，默认为window
	 */
	function _register(funcName, funcParam, namespace) {
		var _thisFunc = {};
		_thisFunc.funcName = funcName;
		_thisFunc.funcParam = funcParam;
		_thisFunc.namespace = namespace;
		funcArray.push(_thisFunc);
	}
	
	/**
	 * 执行函数数组
	 */
	function _executeRenderFunc() {
		if(funcArray instanceof Array) {
			var _length = funcArray.length;
			for(var i=0;i<_length;i++) {
				var thisFunc = funcArray[i];
				
				var _func = null;
				if(thisFunc.namespace) {
					_func = window[thisFunc.namespace][thisFunc.funcName]; 
				}else {
					_func = window[thisFunc.funcName];
				}
				
				if(typeof _func == "function") {
					if(!(thisFunc.funcParam instanceof Array)) {
						thisFunc.funcParam = thisFunc.funcParam?[thisFunc.funcParam]:[];  
					}
					_func.apply(window,thisFunc.funcParam);  
				}
			}
		}
	}
	
	return {
		register: _register, //注册一个函数
		executeRenderFunc: _executeRenderFunc//执行函数数组
	};
	
})();

/**
 * 加载公共资源模块 
 */
ebdpui.resload = (function(){
		
	/**
	 * 使用DOM Element创建script标签的方式加载js资源
	 * @param (url) 资源路径
	 * @param (callback) 资源加载完回调函数
	 */
	 function _loadScriptDomElement(url, callback) {
		var domscript = document.createElement('script');
		domscript.src = url;
		if(callback) {
			domscript.onloadDone = false;
			domscript.onload = callback;
			domscript.onreadystatechange = function() {
				if(("loaded"===domscript.readyState||"complete"===domscript.readyState)&&!domscript.onloadDone) {
					domscript.onloadDone = true;
					domscript.onload();
				}
			};
		}
		document.getElementsByTagName('head')[0].appendChild(domscript);
	}
	 /**
	  * 使用document.write方式加载js资源
	  * @param (url) 资源路径
	  * @param (callback) 资源加载完回调函数
	 */
	 function _loadScriptDocWrite(url, callback) {
		 document.write('<scr' + 'ipt src="' + url + '" type="text/javascript"></scr' + 'ipt>');
		 if(callback) {
			_addHandler(window, "onload", callback);
		 }
	 }
	 
	 /**
	  * 使用document.write方式加载css资源
	  * @param (url) 资源路径
	  */
	 function _loadStyleDocWrite(url) {
		 document.write('<li' + 'nk href="' + url + '" rel="stylesheet" type="text/css" />');
	 }
		
	 /**
	  * 添加事件
	  * @param (elem) 元素
	  * @param (type) 事件类型
	  * @param (func) 事件回调函数
	 */
	 function _addHandler(elem, type, func) {
		 if(elem.addEventListener) {
			elem.addEventListener(type, func, false);
		 }else if(elem.attachEvent) {
			elem.attachEvent("on"+type, func);
		 }
	 }
	 
	 /**
	  * 加载单个js脚本
	  * @param (url) 资源路径
	  * @param (onload) 资源加载完回调函数
	  */
	 function _loadScript(url, callback) {
		 _loadScriptDocWrite(url, callback);
	 }
	 
	 /**
	  * 加载多个js脚本
	  * @param (urlArray) 资源路径数组
	  * @param (onload) 资源加载完回调函数
	  */
	 function _loadScripts(urlArray, callback) {
		 var nUrls = urlArray.length;
		 for(var i=0;i<nUrls;i++) {
			 _loadScriptDocWrite(aUrls[i],(i+1 == nUrls ? callback : null)); 
		 }
	 }
	 
	 /**
	  * 加载单个css脚本
	  * @param (url) 资源路径 
	  */
	 function _loadStyle(url) {
		 _loadStyleDocWrite(url);
	 }
	 
	 /**
	  * 加载多个css脚本
	  * @param (urlArray) 资源路径数组
	  */
	 function _loadStyles(urlArray) {
		 for(var i=0;i<urlArray.length;i++) {
			 _loadStyleDocWrite(url);
		 }
	 }
	 
	 /**
	  * 判断是否是js资源
	  * @param (path) 资源路径
	  * @return (Boolean) 
	  */
	 function _isJSScript(path) {
		 var lastIndex = path.lastIndexOf(".");
		 if(path.substring(lastIndex) == '.js') {
			 return true;
		 }
		 return false;
	 }
	 
	 /**
	  * 判断是否是css资源
	  * @param (path) 资源路径
	  * @return (Boolean) 
	  */
	 function _isCss(path) {
		 var lastIndex = path.lastIndexOf(".");
		 if(path.substring(lastIndex) == '.css') {
			 return true;
		 }
		 return false;
	 }
	 
	 /**
	  * 整合路径
	  * @param (baseUrl) 基准路径
	  * @param (path) 相对于基准路径的资源路径
	  * @(return) (String) 资源完整路径
	  */
	 function _composePath(baseUrl, path) {
		 var ret = "";
		 var _baseUrl = baseUrl;
		 var _path = path;
		 
		 while(_baseUrl.slice(-1)=="/") {
			 var _lastIndex = _baseUrl.lastIndexOf("/");
			 _baseUrl = _baseUrl.substring(0,_lastIndex);
		 }
		 
		 while(_path.indexOf("../")!=-1) {
			 var _firstIndex =  _path.indexOf("..");
			 _path = _path.substring(_firstIndex + 3);
		 }
		 
		 ret = _baseUrl + "/" + _path;
		 return ret;
	 }
	  
	 /**
	  * 加载js、css资源
	  * @param (baseUrl) 基准url
	  * @param (pathArray) 资源相对于url的路径数组
	  * @param (entirePathArray)　资源如果不基于基准url,在此配置完整url路径数组
	  */
	function _create(baseUrl, pathArray, entirePathArray) { 
		/** 加载pathArray中资源 */
		if(pathArray && pathArray instanceof Array) {
			for(var i=0;i<pathArray.length;i++) {
				if(_isJSScript(pathArray[i])) { 
					//_loadScriptDocWrite(baseUrl+pathArray[i]);
					_loadScriptDocWrite(_composePath(baseUrl, pathArray[i])); 
				}else if(_isCss(pathArray[i])) {
					//_loadStyleDocWrite(baseUrl+pathArray[i]);
					_loadStyleDocWrite(_composePath(baseUrl, pathArray[i]));
				}
			} 
		}
		/** 加载entirePathArray中资源 */
		if(entirePathArray && entirePathArray instanceof Array) {
			for(var i=0;i<entirePathArray.length;i++) {
				if(_isJSScript(entirePathArray[i])){
					_loadScriptDocWrite(entirePathArray[i]);
				}else if(_isCss(entirePathArray[i])) {
					_loadStyleDocWrite(entirePathArray[i]);
				} 
			}
		}
	}
	
	/**
	 * 串联加载指定的脚本，异步逐个加载，等数组中前一个加载完后才加载下一个
	 * 全部加载完后执行callback回调函数
	 * @param baseUrl 基准路径
	 * @param array 脚本数组
	 * @param callback 脚本加载完回调函数
	 */
	function _seriesLoadScripts(baseUrl, scripts, callback) {
		if(scripts && typeof scripts != "object") {
			var scripts = [scripts];
		}
		var head = document.getElementsByTagName("head")[0] || document.documentElement;
		var s = new Array();
		var last = scripts.length - 1;
		var recursiveLoad = function(i) {//递归加载函数
			s[i] = document.createElement("script");
			s[i].setAttribute("type", "text/javascript");
			s[i].onload = s[i].onreadystatechange = function() {
				if(!/*@cc_on!@*/0 || this.readyState == "loaded" || this.readyState == "complete") {//第一个为条件编译，针对非ie浏览器
					this.onload = this.onreadystatechange = null;
					if(i != last) {
						recursiveLoad(i+1);
					}else if(typeof callback == "function") {
						callback();
					}
				}
			}
			s[i].setAttribute("src", baseUrl+"/"+scripts[i]);
			head.appendChild(s[i]);
		};
		recursiveLoad(0);
	}
	 
	 return {
		 loadScript: _loadScript,/** 加载单个js脚本 */
		 loadScripts: _loadScripts,/** 加载多个js脚本 */
		 loadStyle: _loadStyle,/** 加载单个css脚本 */ 
		 loadStyles: _loadStyles,/** 加载多个css脚本 */
		 create:_create,/** 加载js、css资源 */
		 seriesLoadScripts:_seriesLoadScripts/** 串联加载多个脚本 */
	 };
	 
})(); 


/**
 * PC测试模块
 */ 
ebdpui.debug = (function(){
	
	var ele1 = document.getElementById(IFOP_DEBUG_FLAG1);
	var ele2 = document.getElementById(IFOP_DEBUG_FLAG2);
	
	/**
	 * 判断是否是debug模式
	 * @return {Boolean}
	 */
	function _isDebug() {
		if(document.getElementById(IFOP_DEBUG_FLAG1)||document.getElementById(IFOP_DEBUG_FLAG2)) {
			return true;
		}
		return false;
	}
	
	/**
	 * 初始化，包括数据赋值等
	 */
	function _init() {
		//initData赋值
		if(document.getElementById(IFOP_DEBUG_FLAG1)) {
			var _initData = document.getElementById(IFOP_DEBUG_FLAG1).innerText;
			var _localStorage = ebdpui.cache.getLocalStorage();
			_localStorage.setItem(IFOP_INIT_DATA_ITEM_KEY, _initData);
		}
		//session和op data赋值
		if(document.getElementById(IFOP_DEBUG_FLAG2)) {
			var _sessionAndOpData = document.getElementById(IFOP_DEBUG_FLAG2).innerText; 
			var _sessionStorage = ebdpui.cache.getSessionStorage();
			_sessionStorage.setItem(IFOP_SESSIONANDOP_DATA_ITEM_KEY, _sessionAndOpData);	
		}
	}
	
	return {
		isDebug: _isDebug,//是否是debug模式
		init: _init//初始化
	};
})();

/**
 * form提交是否拦截设置模块
 */ 
ebdpui.form = (function(){
	/** 是否拦截form，默认为true */
	var _isIntercept = true;
	
	/**
	 * 设置是否拦截
	 * @param isIntercept
	 */
	function _setIsIntercept(isIntercept) {
		_isIntercept = isIntercept;
	}
	
	/**
	 * 获取是否拦截
	 * @return boolean
	 */
	function _getIsIntercept() {
		return _isIntercept;
	}
	
	return {
		setIsIntercept: _setIsIntercept,//设置是否拦截
		getIsIntercept: _getIsIntercept//获取是否拦截
	}
})();


/**
 * 在onload函数里执行拦截form操作
 */
(function(){
	/**
	 * 拦截form进行操作
	 */
	function _formtoJson(formObj) {
		var paramObject = new Object();
		if (formObj) {
			var elementsObj = formObj.elements;
			var obj;
			if (elementsObj) {
				for ( var i = 0; i < elementsObj.length; i += 1) {
					obj = elementsObj[i];
					if (obj.name != undefined && obj.name != "") {
						if(obj.disabled){
							continue;
						}
						if(obj.tagName.toLowerCase()=='input'&&obj.type.toLowerCase()=='checkbox'&&obj.checked==false){
							continue;
						}
						if(obj.tagName.toLowerCase()=='input'&&obj.type.toLowerCase()=='radio'&&obj.checked==false){
							continue;
						}
						if(obj.tagName.toLowerCase()=='select'&&obj.value==''){
							continue;
						}
						//添加了对中文url的编码
						paramObject[obj.name] = encodeURIComponent(obj.value);
					}

				}
			} else {
				//alert("没有elements对象!");
				return;
			}
		} else {
			//alert("form不存在!");
			return;
		}
		return _JsonToString(paramObject);
	}
	function _JsonToString(o) {
		var arr = [];
		var fmt = function(s) {
			if (typeof s == 'object' && s != null)
				return JsonToString(s);
			//return /^(string|number)$/.test(typeof s) ? "" + s + "" : s;
			return s;
		}
		for ( var i in o)
			arr.push("" + i + "=" + fmt(o[i]));
			//arr.push("'" + i + "':" + fmt(o[i]));
		return arr.join('&'); 
		//return '{' + arr.join(',') + '}';
	}
	function _interceptFormSubmit() {
		if(!ebdpui.form.getIsIntercept()) {
			return;
		}
		var oldSubmit;
		var forms = document.forms;
		for ( var i = 0; i < forms.length; i++) {
			var _form = forms[i];
			if (_form != null && _form != 'undefined') {
				/** 备份submit函数 */
				_form.oldSubmit = _form.submit;
				/**  覆盖submit函数以实现拦截 */
				_form.submit = function() {
					/** 如果是Android,且是post请求，则修改为get请求 */
					//if(ICBCUtilTools.isAndroid() && _form.method.toUpperCase() == "POST") {
						//_form.method = "get";
						/** 调用原函数来提交 */ 
						//this.oldSubmit();
					//}
					var formJsonData = {};
					var _url = this.action;
					var _paramValue = _formtoJson(this);
					if(this.method.toUpperCase() == "GET") {
						if(_url.indexOf("?")==-1) {
							_url += "?"+_paramValue;
						}else {
							_url += "&"+_paramValue;
						}
						_paramValue = '';
					}
					formJsonData.url = _url;
					formJsonData.param = _paramValue;
					ebdpui.native.setFormData(formJsonData); 
					//console.log(JSON.stringify(formJsonData));
				}; 
			}
		}
	}
	if (window.attachEvent) {
		window.attachEvent("onload", _interceptFormSubmit); 
	} else if (window.addEventListener) {
		window.addEventListener("load", _interceptFormSubmit,false); 
	}
})();

/**
 * 定义与BTT环境相关的取值赋值的类
 */
var initializationUTB=(function(){
	function DSEJspContextServices() {
		this.HtmlConstants={
				"OPERATIONNAME":"dse_operationName",
				"SESSIONID":"dse_sessionId",
				"APPLICATIONID":"dse_applicationId",
				"PAGEID":"dse_pageId",
				"PROCESSORID":"dse_processorId"
					};
		this.data=ebdpui.unformat.getData();
		this.sessionData=ebdpui.unformat.getSessionData();
		this.opData=ebdpui.unformat.getOpData();
		//定义一些与bttsetting相关的固定的变量
		//this.autoTest="0";/**自动化测试开关，0关，1开，综合环境设置1，模测和生产设置0 */
		
		
	}
	/**
	 * 得到bttcontext里key所对应的的value值，支持点的分割
	 */
	DSEJspContextServices.prototype.getStringValue = function(key) {
		var value=this.data.getValueAt(key);
		if(value.constructor.name=='Empty'){
			return null;
		}else{
			return value;
		}
		
	};
	/**
	 * 得到一些常量
	 */

	DSEJspContextServices.prototype.getHtmlConstants = function(key) {
		return this.HtmlConstants[key];
	};

	/**
	 * 得到pageId
	 */
	DSEJspContextServices.prototype.getPageId = function() {
		var value=this.sessionData.getValueAt(this.getHtmlConstants("PAGEID"));
		if(value.constructor.name=='Empty'){
			return "";
		}else{
			return value;
		}
	};
	/**
	 * 得到SessionId
	 */
	DSEJspContextServices.prototype.getSessionId = function() {
		var value=this.sessionData.getValueAt(this.getHtmlConstants("SESSIONID"));
		if(value.constructor.name=='Empty'){
			return "";
		}else{
			return value;
		}
	};
	/**
	 * 得到AppId
	 */
	DSEJspContextServices.prototype.getAppId = function() {
		var value=this.sessionData.getValueAt(this.getHtmlConstants("APPLICATIONID"));
		if(value.constructor.name=='Empty'){
			return "";
		}else{
			return value;
		}
	};
	/**
	 * 得到ProcessId
	 */
	DSEJspContextServices.prototype.getProcessId = function() {
		var value=this.sessionData.getValueAt(this.getHtmlConstants("PROCESSORID"));
		if(value.constructor.name=='Empty'){
			return "";
		}else{
			return value;
		}
	};
	/**
	 * 得到整体数据包括sessionData与opData
	 */
	DSEJspContextServices.prototype.getContext = function() {
		return this.data;
		
	};
	/**
	 * 得到整体数据包括sessionData
	 */
	DSEJspContextServices.prototype.getSessionContext = function() {
		return this.sessionData;
		
	};
	/**
	 * 得到整体数据opData
	 */
	DSEJspContextServices.prototype.getOpContext = function() {
		return this.opData;
	};

	/**
	 * 得到kColl中key所对应的值
	 */
	DSEJspContextServices.prototype.getValueFromKcoll = function(kColl,key) {
		var resultOfKColl=this.data.getKeyedCollection(kColl);
		if(resultOfKColl.constructor.name== 'KeyedCollection'){
			return resultOfKColl.getValueAt(key);
		}
		
	};
	/**
	 * 得到icoll中index索引中key所对应的值
	 */
	DSEJspContextServices.prototype.getValueFromIcoll = function(iColl,index,key) {
		var resultOfIColl=this.data.getIndexedCollection(iColl);
		if(resultOfIColl.constructor.name== 'IndexedCollection'){
			return resultOfIColl.getElementAt(index).getValueAt(key);
		}
	};
	/**
	 * 得到基本的web路径
	 */
	DSEJspContextServices.prototype.getBaseWebPath = function() {
		
	};

	/**组织sessionId的隐藏域*/
	DSEJspContextServices.prototype.getSessionIdHtmlField = function() {
		return "<input type=\"hidden\" name=\"" + this.getHtmlConstants("SESSIONID") + "\" value=\"" + this.getSessionId() + "\" />";
	};
	/**组织appId的隐藏域*/
	DSEJspContextServices.prototype.getApplicationIdHtmlField=function(){
		return  "<input type=\"hidden\" name=\"" + this.getHtmlConstants("APPLICATIONID") + "\" value=\"" + this.getAppId() + "\" />";
	};
	/**组织pageId的隐藏域*/
	DSEJspContextServices.prototype.getPageIdHtmlField=function(){
		return  "<input type=\"hidden\" name=\"" + this.getHtmlConstants("PAGEID") + "\" value=\"" + this.getPageId() + "\" />";
	};

	/**组织get请求的sessionid*/
	DSEJspContextServices.prototype.getSessionIdHtmlGetField= function() {
		/** java里有getTagId的逻辑，js目前先没有实现 */
//		var getTagId=function(type,typeParam){
//			
//		}
//		if(this.autoTest=='1'){
//			return this.getHtmlConstants("SESSIONID")+"=" + this.getSessionId()+getTagId("get","a");
//		}else{
		return this.getHtmlConstants("SESSIONID")+"=" + this.getSessionId();
//		}
	}
	/**组织get请求的appid*/
	DSEJspContextServices.prototype.getApplicationIdHtmlGetField=function(){
		return this.getHtmlConstants("APPLICATIONID") +"=" + this.getAppId();//$NON-NLS-2$//$NON-NLS-1$
		
	}
	/**组织get请求的pageid*/
	DSEJspContextServices.prototype.getPageIdHtmlGetField=function(){
		return this.getHtmlConstants("PAGEID") +"=" + this.getPageId();//$NON-NLS-2$//$NON-NLS-1$
		
	}



	/**
	 * 生成input表单
	 */
	DSEJspContextServices.prototype.getRequiredHtmlFields = function(parentCtx,opName) {
		//目前java方法中parentCtx也没有用，当前为了跟java方法对应，故设置了此参数
		var htmlFieldsStr="";
		if(opName){
			htmlFieldsStr=htmlFieldsStr+this.getSessionIdHtmlField();
			htmlFieldsStr=htmlFieldsStr+this.getApplicationIdHtmlField();
			htmlFieldsStr=htmlFieldsStr+this.getPageIdHtmlField();
			htmlFieldsStr=htmlFieldsStr+("<input type=\"hidden\" name=\"")+this.getHtmlConstants("OPERATIONNAME")+"\" value=\""+opName+"\" />";
			var processId=(this.sessionData.getValueAt(this.getHtmlConstants("PROCESSORID")));
			if(!(processId.constructor.name=='Empty'||processId=='')){
				htmlFieldsStr=htmlFieldsStr+("<input type=\"hidden\" name=\"")+this.getHtmlConstants("PROCESSORID")+"\" value=\""+this.getProcessId()+"\" />";
			}
		}
		return htmlFieldsStr;	
	};
	/**
	 * 生成上送表单(get请求)
	 */
	DSEJspContextServices.prototype.getRequiredGetParameter = function(parentCtx,opName) {
		//目前java方法中parentCtx也没有用，当前为了跟java方法对应，故设置了此参数
		var htmlFieldsStr="";
		if(opName){
			htmlFieldsStr=htmlFieldsStr+this.getSessionIdHtmlGetField()+"&";
			htmlFieldsStr=htmlFieldsStr+this.getApplicationIdHtmlGetField()+"&";
			htmlFieldsStr=htmlFieldsStr+this.getPageIdHtmlGetField()+"&";
			htmlFieldsStr=htmlFieldsStr+this.getHtmlConstants("OPERATIONNAME")+"="+opName+"&";
			
			var version=this.sessionData.getValueAt("WAPOptions.version");
			if(version.constructor.name== 'Empty'||version==''){
				version="3";
			}
			htmlFieldsStr=htmlFieldsStr+"wapVersion"+"="+version;	
				
			//这个是需要在setting里读取(目前不需要)
			var processId=(this.sessionData.getValueAt(this.getHtmlConstants("PROCESSORID")));
			if(!(processId.constructor.name== 'Empty'||processId=='')){
				htmlFieldsStr=htmlFieldsStr+"&"+this.getHtmlConstants("PROCESSORID")+"="+this.getProcessId();
			}
		}
		return htmlFieldsStr;
		
	};
	/**
	 * 生成input表单元素
	 */
	DSEJspContextServices.prototype.getRequiredXHtmlFields = function(parentCtx,opName) {
		//目前java方法中parentCtx也没有用，当前为了跟java方法对应，故设置了此参数
		var htmlFieldsStr="";
		if(opName){
			htmlFieldsStr=htmlFieldsStr+this.getRequiredHtmlFields("",opName);
			
			var version=this.sessionData.getValueAt("WAPOptions.version");
			if(version.constructor.name== 'Empty'||version==''){
				version="3"; 
			}
			
			htmlFieldsStr=htmlFieldsStr+("<input type=\"hidden\" name=\"")+"wapVersion"+"\" value=\""+version+"\" />";
			////这个是需要在setting里读取(目前不需要)
		}
		return htmlFieldsStr;
	};
	
	return new DSEJspContextServices();

});



ebdpui.parseTag=(function(){  //jquery不要了
	return{
		parseICBCLabel:function(){
			var $parseObj=null,$currentObj=null;			
			$parseObj=jQuery("icbc_label");			
			$parseObj.each(function(i){
				$currentObj=jQuery(this);
				$currentObj.after(ebdpui.utb.getStringValue($currentObj.attr("data-name")));
			})
			
		},
		parseICBCLabelInTag:function(IDArray){
			var $parseObj=null,$currentObj=null,icbcLabelAttr="";
			parseLabelStartTime=new Date().getTime();
			if(IDArray){
				var len=IDArray.length;
				for(var i=0;i<len;i++){
					var jsObj=document.getElementById(IDArray[i]);
					icbcLabelAttr=jsObj.getAttribute("icbc-label-attr");
					if(icbcLabelAttr){
						jsObj.setAttribute(icbcLabelAttr,ebdpui.utb.getStringValue(jsObj.getAttribute("icbc-label")));
					}else{
						jsObj.value=(ebdpui.utb.getStringValue(jsObj.getAttribute("icbc-label")));
					}
				}
			}else{
				$parseObj=jQuery("[icbc-label]");
				$parseObj.each(function(i){
					$currentObj=jQuery(this);
					icbcLabelAttr=$currentObj.attr("icbc-label-attr");
					if(icbcLabelAttr){
						$currentObj.attr(icbcLabelAttr,ebdpui.utb.getStringValue($currentObj.attr("icbc-label")));
					}else{
						$currentObj.val(ebdpui.utb.getStringValue($currentObj.attr("icbc-label")));
					}
					
				})
			}
			parseLabelEndTime=new Date().getTime();

			
		},
		parseICBCIf:function(){
			var $parseObj=jQuery("icbc_if");
			$parseObj.each(function(i){
				var $currentObj=jQuery(this);
				if(!ebdpui.utb.getStringValue($currentObj.attr("judge"))){
					$currentObj.remove();//remove 效率问题
				}else{
					if($currentObj.find("icbc_if").length==0){
						$currentObj.replaceWith($currentObj.html());
					}else{
						var $currentChildren=$currentObj.children();
						for(var i=$currentChildren.length-1;i>=0;i--){
							$currentObj.after($currentChildren[i]);
						}
						$currentObj.remove();
					}
				}
			});
		},
		parseBttParam:function($){
			var $parseObj=jQuery("icbc_bttParam");
			$parseObj.each(function(i){
				var $currentObj=jQuery(this);
				$currentObj.after(ebdpui.utb.getRequiredXHtmlFields("",$currentObj.attr("opname")));
			});
		}
		//应该可以根据实际情况进行新增，如果涉及构造对象的方式(一般含有自己的私有属性和方法)，可以在这里进行new的操作，并把响应的对象作为返回
		//其他的可以作为工具方法来实现
	}
})();

ebdpui.executePublicFunc=function(){
	//执行公共的函数
	loadPublicVariable();
	createMoreBtnAndBTip();
}



//-----------------------------------定义UI组件基础类-------------------------------------------//
/**
 * 构造函数
 * @param {Object} id		组件id
 * @param {Object} basicID	组件id挂载的ID
 * @param {Object} attrJSON	组件需要的参数
 * 
 */
function BaseUIForEbankP(id,basicID,attrJSON) {
	this.id = id;
	this.basicID=basicID;
	this.attrJSON=attrJSON;
	this.visible = true;
	this.enable = true;
	this.value = null;
	
	this.mount=attrJSON["mount"];
	
	this.HTML="";//创建dom的HTML字符串，并在createDOM方法里对此值进行赋值
	
	this.$component=null;
	this.$basicComponent=jQuery("#"+this.basicID).length==0?jQuery("body"):jQuery("#"+this.basicID);
	
}

/**
 * 设置当前组件id
 * @param {Object} id
 */
BaseUIForEbankP.prototype.setId = function(id) {
	this.id = id;
};

/**
 * 查询当前组件id
 */
BaseUIForEbankP.prototype.getId = function() {
	return this.id;
};

/**
 * 设置当前组件是否可见
 * @param {Object} visible
 */
BaseUIForEbankP.prototype.setVisible = function(visible) {
	if(this.visible != visible){
		this.visible = visible;
		if(visible){
			this.$component.show();
		}else{
			this.$component.hide();
		}
	}
	
	
};

/**
 * 获取当前组件是否可见
 */
BaseUIForEbankP.prototype.isVisible = function() {
	return this.visible;
};

/**
 * 设置组件是否能够点击，设置enable会影响到组件外观，需要在子类中具体进行实现
 * @param {Object} enable
 */
BaseUIForEbankP.prototype.setEnable = function(enable) {
	if(this.enable != enable){
		this.enable = enable;
		if(enable){
			this.bindEvent();
		}else{
			this.unbindEvent();
		}
	}
};

/**
 * 得到当前组件是否可用
 * @param {Object} enable
 * @return {Boolean}
 */
BaseUIForEbankP.prototype.isEnable = function(enable) {
	return this.enable;
};
/**
 * 得到attrJSON中key所对于的属性值
 * @param {Object} key
 */
BaseUIForEbankP.prototype.getAttr = function(key) {
	return this.attrJSON[key];
};
/**
 * 设置attrJSON中key所对于的属性值
 * @param {String}attr:传入参数的名称
 * @param {String}type:1标示其需要在context里取值
 * @param {String}defaultValue:默认值
 * @param {Array}valueRange:值的取值范围
 */
BaseUIForEbankP.prototype.setAttr = function(attr,type,defaultValue,valueRange) {
	if(attr!=undefined&&attr!=null){
		var attrValue=(type==1)?(ebdpui.utb.getStringValue(attr)):attr;
		if(valueRange){
			if(jQuery.inArray(attr,valueRange)==-1 ){
				returnValue=(jQuery.inArray(defaultValue,valueRange)==-1)?valueRange[0]:defaultValue;
			}else{
				return attrValue;
			}
		}else{
			return attrValue;
		}
		
	}else{
		return defaultValue;
	}
};
/**
 * 根据arraylist，循环执行保持arraylist项目的函数，为功能函数
 * @param {Array}arraylist:循环的数组
 * @param {String}func:循环是所执行的函数
 */
BaseUIForEbankP.prototype.each = function(arrayList,func) {
	var len=arrList.length;
	for (var i = 0; i < len; i++) {
		fun(arrList[i], i); 
	}
};

/**
 * 构件添加到指定元素中
 * @param {String}elementID	元素id
 * @param {String}mount		挂载的方式
 */
BaseUIForEbankP.prototype.rendTo = function(mount){
	var mountRange=['append','appendTo','after','before'];
	if(jQuery.inArray(mount,mountRange)==-1 )mount='append';
	var $baseEleObj=jQuery("#"+this.basicID),$selfObj=jQuery("#"+this.id);
	if(mount==='append'){
		this.$component.appendTo(this.$basicComponent);
	}else if(mount==='appendTo'){
		this.$basicComponent.append(this.$component);
	}else if(mount==='after'){
		this.$basicComponent.after(this.$component);
	}else if(mount==='before'){
		this.$basicComponent.before(this.$component);
	}
	
};

/**
 * 根据index得到JSON中某一项的值
 * @param {String}elementID	元素id
 * @param {Sring}mount		挂载的方式
 */
BaseUIForEbankP.prototype.getValueByIndex = function(jsonArray,index){
	var returnJSON=null;
	if(index>0&&index<jsonArray.length){
		returnJSON=jsonArray[index];
	}
	return returnJSON;
};

/**
 * 根据KEY得到JSON中某一项的值
 * @param {JSON}JSON		JSON对象
 * @param {String}mount		挂载的方式
 */
BaseUIForEbankP.prototype.getValueByKey = function(jsonArray,key,basicKey){
	var returnJSON=null;
	var len=jsonArray.length;
	for(var i=0;i<len;i++){
		if(key==jsonArray[i][basicKey]){
			returnJSON=jsonArray[i];
			break;
		}
	}
	return returnJSON;
};

/**
 * 生成一个form表单
 * inputFieldArray每一项包含属性：name，type(默认值为hidden)，value：根据valueType计算，valueType(为1时标示在context中取的)
 */
BaseUIForEbankP.prototype.createForm = function(formName,action,opName,inputFieldArray) {
	var HTMLStr="<form id=\""+formName+"\"  name=\""+formName+"\" action =\"" + action + "\">";
	if(opName){
		HTMLStr=HTMLStr+ebdpui.utb.getRequiredXHtmlFields(opName);//btt上送参数的部分
	}

	//用户字定义上送参数
	var len=inputFieldArray.length;
	var tmpType='hidden',tmpName,tmpValue,tempValueType=0;
	for(var i=0;i<len;i++){
		tmpType=inputFieldArray[i]["type"];
		tmpName=inputFieldArray[i]["name"];
		tempValueType=inputFieldArray[i]["valueType"];
		tmpValue=(tempValueType==1)?(ebdpui.utb.getStringValue(inputFieldArray[i]["value"])):inputFieldArray[i]["value"];
		
		HTMLStr=HTMLStr+"<input type='"+(tmpType?tmpType:"hidden")+"'";
		HTMLStr=HTMLStr+(tmpName?" name='"+tmpName+"'":"");
		HTMLStr=HTMLStr+(tmpValue!=undefined&&tmpValue!=null)?" value='"+tmpValue+"'":"";
		HTMLStr=HTMLStr+"/>";
	}
	HTMLStr=HTMLStr+"</form>";
	return HTMLStr;
};


/**
 * 返回一个a标签的html，且会为href自动拼接btt固定上送的参数
 */
BaseUIForEbankP.prototype.createAElement = function(id,url,text,opName,paramArray) {
	var opParamStr="",normalParamStr="";
	var paramArrayLen=paramArray.length;
	var tmpName,tmpValue,tmpType=0;
	var tmpIndex=0;//自增的判断
	var HTMLStr=HTMLStr+"<a id='"+id+"'";
	HTMLStr=HTMLStr+url?" href='"+url:"";
	
	if(opName){
		opParamStr=ebdpui.utb.getRequiredGetParameter(opName);
	}
	
	for(var i=0;i<paramArrayLen;i++){
		tmpName=paramArray[i]["name"];
		tmpType=paramArray[i]["type"];
		tmpValue=(tmpType==1)?(ebdpui.utb.getStringValue(paramArray[i]["value"])):paramArray[i]["value"];
		if(tmpName&&tmpValue!=undefined&&tmpValue!=null){
			if(tmpIndex==0){
				normalParamStr=normalParamStr+tmpName+"="+tmpValue;
			}else{
				normalParamStr="&"+normalParamStr+tmpName+"="+tmpValue;
			}
			
		}
	}
	if(opParamStr){
		HTMLStr=HTMLStr+"?"+opParamStr;
		if(normalParamStr){
			HTMLStr=HTMLStr+"&"+normalParamStr;
		}
	}else if(normalParamStr){
		HTMLStr=HTMLStr+"?"+normalParamStr;
	}
	
	HTMLStr=HTMLStr+"'>";
	HTMLStr=HTMLStr+text+"</a>";
};

/**
 * 根据attrJson设置基本属性，应用自己处理
 */
BaseUIForEbankP.prototype.setInputParam = function() {
	
};
/**
 * 初始化构件所需要的数据,应该自己处理
 */
BaseUIForEbankP.prototype.dealData = function() {
	
};
/**
 * 拼接构件内部的HTML
 */
BaseUIForEbankP.prototype.createDOM = function() {
	//ID为最外层DOM的标示，并对this.HTML进行赋值
	this.HTML="basic";
	
};

/**
 * 初始化构件所需要对象
 */
BaseUIForEbankP.prototype.initJQObj = function() {
	this.$component=jQuery(this.HTML);
};


BaseUIForEbankP.prototype.unbindEvent = function() {
	
};
/**
 * 为构件绑定事件
 */
BaseUIForEbankP.prototype.bindEvent = function() {
	this.unbindEvent();
};


/**
 * 在组件展示状态对其中Html元素进行一些处理
 */
BaseUIForEbankP.prototype.show = function() {
	this.setAttr();/**根据attrJson设置基本属性*/	
	this.dealData();/**初始化构件所需要的数据*/
	this.createDom();/**拼接构件内部的HTML*/
	this.initJQObj();/**初始化构件所需要对象*/
	this.bindEvent();/**为构件绑定事件*/
	this.rendTo(this.mount);/**将构件挂载到dom中*/
};

/**
 * 工具类
 */
var ICBCUtilTools = {
	sUserAgent : navigator.userAgent.toLowerCase(),
	isTestMode:function(){
		if(window['mode']=='test')
			return true;
		else
			return false;
	},
	isNewAMTMode:function(){
		if(window['AMTMode']=='new')
			return true;
		else
			return false;
	},
	decodeWindowUserAgent : function(){
		if(window['user-agent']!=undefined){
			window['user-agent']=decodeURIComponent(window['user-agent']).replace(/\+/g, " ");
		}
	},
	isiPhone : function() {
		if((this.sUserAgent.match(/iphone os/i) == "iphone os")||(this.sUserAgent.match(/ipad/i) == "ipad"))
			return true;
		else
			return false;
	},
	isAndroid : function() {
		return (this.sUserAgent.match(/android/i) == "android");
	},
	isWindowsPhone : function(){
		return (this.sUserAgent.match(/msie/i) == "msie");
	},
	isWindowsPhone7 : function(){
		return (this.sUserAgent.match(/msie 9.0/i) == "msie 9.0");
	},	
	isICBCiPhoneClient : function() {
		return (this.sUserAgent.match(/icbciphonebs/i) == "icbciphonebs");
	},
	isICBCAndroidClient : function() {
		return (this.sUserAgent.match(/icbcandroidbs/i) == "icbcandroidbs");
	},
	isICBCWindowsPhoneClient : function() {
		return (this.sUserAgent.match(/icbcwindowsphonebs/i) == "icbcwindowsphonebs");
	},
	isDirectBankClient : function() {
		if(window['user-agent']!=undefined){
			return (window['user-agent'].toLowerCase().match(/directbank/i) == "directbank");
		}else{
			return (this.sUserAgent.match(/directbank/i) == "directbank");
		}
	},	
	isCollegeClient : function() {
		if(window['user-agent']!=undefined){
			return (window['user-agent'].toLowerCase().match(/college/i) == "college");
		}else{
			return (this.sUserAgent.match(/college/i) == "college");
		}
	},
	isEmallClient : function() {
		return (this.sUserAgent.match(/f-emall/i) == "f-emall");
	},
	isWAPBClient : function() {
		return (this.sUserAgent.match(/f-wapb/i) == "f-wapb");
	},
	getAndroidVersion : function() {
		try {
			var version = this.sUserAgent.match(new RegExp('(?:android[\\s|/])(\\d\.\\d\.\\d)'))[1];
			version = (version == undefined ? "" : version);
			version = parseInt(version.replace(/\./g, ''));
			return version;
		} catch (e) {
			try{
				var version=this.sUserAgent.match(new RegExp('(?:android[\\s|/])(\\d\.\\d)'))[1]+"0";
				version = (version == undefined ? "" : version);
				version = parseInt(version.replace(/\./g, ''));
				return version;
			}catch(e){
				return 100;
			}
		}
	},
	getAndroidClientVersion : function() {
		try {
			if (this.isAndroid()) {
				if(this.isDirectBankClient()){
					var version = this.sUserAgent.match(new RegExp('baseversion:(\\d\.\\d\.\\d\.\\d)'));
					version = (version == undefined ? "" : version);
					version = parseInt(version[1].replace(/\./g, ''));
					version = (version==""?"1000":version);
					return version;
				}else{
					var version = this.sUserAgent.match(new RegExp('\\d\.\\d\.\\d\.\\d'));
					version = (version == undefined ? "" : version);
					version = parseInt(version[0].replace(/\./g, ''));
					version = (version==""?"1000":version);
					return version;
				}
			}
		} catch (e) {
			return "1000";
		}
	},
	getAndroidClientFullVersion : function() {
		try {
			if (this.isAndroid()) {
				var version = this.sUserAgent.match(new RegExp('fullversion:(\\d+)'));
				version = (version == undefined ? "0" : version);
				version = parseInt(version[1].replace(/\./g, ''));
				return version;
			}
		} catch (e) {
		}
	},
	getiPhoneClientFullVersion : function(userAgent) {
		try {
			if (this.isiPhone()) {
				if(this.isDirectBankClient()){
					var version = userAgent.match(new RegExp('basefullversion:(\\d\.\\d\.\\d\.\\d\.\\d)'));
					if(version==undefined){
						version = userAgent.match(new RegExp('basefullversion:(\\d\.\\d\.\\d\.\\d)'));
					}
					version = (version == undefined ? "0" : version);
					version = parseInt(version[1].replace(/\./g, ''));
					version = (version==""?"1000":version);
					return version;
				}else{
					var version = userAgent.match(new RegExp('fullversion:(\\d\.\\d\.\\d\.\\d\.\\d)'));
					if(version==undefined){
						version = userAgent.match(new RegExp('fullversion:(\\d\.\\d\.\\d\.\\d)'));
					}
					version = (version == undefined ? "0" : version);
					version = parseInt(version[1].replace(/\./g, ''));
					version = (version==""?"1000":version);
					return version;
				}
			}
		} catch (e) {
			return "1000";
		}
	},	
	getWindowsPhoneClientVersion : function() {
		try {
			if (this.isWindowsPhone()) {
				var version = window['user-agent'].match(new RegExp(/\d\.\d\.\d\.\d$/));
				version = (version == undefined ? "" : version);
				version = parseInt(version[0].replace(/\./g, ''));
				version = (version==""?"1000":version);
				return version;
			}
		} catch (e) {
			return "1000";
		}
	},
	isICBCOpenNewClient : function() {
		return (this.sUserAgent.match(/icbcandroidbsnew/i) == "icbcandroidbsnew"||this.sUserAgent.match(/icbciphonebsnew/i) == "icbciphonebsnew"||(window['user-agent'].toLowerCase().match(/icbcwindowsphonebs/i) == "icbcwindowsphonebs"||window['user-agent'].toLowerCase().match(/Windows\sPhone/i) == "windows phone"));
	},
	convertUTF8 : function(text) {
		var temp1 = jQuery("<div></div>").html(text);
		var temp2 = temp1.html();
		temp1.empty();
		return temp2;
	},
	callNative : function(className, methordName, data, callback) {
		try {	
			if (ICBCUtilTools.isAndroid()) {
				var result = prompt(className+'.'+methordName,JSON.stringify(data));
				callback(result);
			}else if (ICBCUtilTools.isiPhone()) {
				ICBCBridge.callHandler(className+'.'+methordName, data, callback);
			}
		} catch (e) {
		}
	},
	checkFormInput : function (formSelect){
		var input=jQuery('form[name='+formSelect+']').find("textarea,input[type=text],input[type=password]");
		input.each(function(){
			var placeholder=(jQuery(this).attr('placeholder')==undefined?"":jQuery(this).attr('placeholder'));
			var value=this.value;
			if(value==placeholder){
				this.value="";
			}
		});
	},
	sleep:function(numberMillis) {
	    var now = new Date();
	    var exitTime = now.getTime() + numberMillis;
	    while (true) {
	        now = new Date();
	        if (now.getTime() > exitTime)
	            return;
	    }
	}

};

/**
 * iOS桥接初始化
 */
(function() {
	if (ICBCUtilTools.isiPhone()){
	    function connectWebViewJavascriptBridge(callback) {
	        if (window.WebViewJavascriptBridge) {
	            callback(WebViewJavascriptBridge);
	        } else {
	            document.addEventListener('WebViewJavascriptBridgeReady', function() {
	                callback(WebViewJavascriptBridge);
	            }, false);
	        }
	    }
	    connectWebViewJavascriptBridge(function(bridge) {
	        bridge.init();
	        bridge.registerHandler('render', function(data,responseCallback){
		    	window.render(data);
		    });
	    });
	    var ICBCBridge = {
	        callHandler: function(name, params, callback) {
	            connectWebViewJavascriptBridge(function(bridge) {
	                bridge.callHandler(name, params, callback);
	            });
	        },
	        send: function(params, callback) {
	            connectWebViewJavascriptBridge(function(bridge) {
	                bridge.send(params, callback);
	            });
	        }
	    };
	    window.ICBCBridge = ICBCBridge;
	}
})();

function domContentLoadedFunc() {
	/**
	 * 数据反序列化和页面渲染
	 */	
	window.ifop_isRepeat = false;
	window.render = function(data) {
		if(!ifop_isRepeat) {
			ifop_isRepeat = true;  
			//执行数据的反序列化
			ebdpui.unformat.getInstance({"data":data,"sessionDataKey":"sessionData","opDataKey":"opData"});
			ebdpui.utb=initializationUTB();
			//执行页面渲染逻辑，执行开发人员在页面里注册的函数
			ebdpui.render.executeRenderFunc(); 
		}
	}
}

document.addEventListener('DOMContentLoaded', domContentLoadedFunc, false); 
